@@ -1,7 +1,7 @@
 from hookman.hooks import HookSpecs
 
 
-def friction_factor(v1: 'int', v2: 'double[2]') -> 'int':
+def friction_factor(v1: "int", v2: "double[2]") -> "int":
     """
     Docs for Friction Factor
         Input:
@@ -12,10 +12,5 @@ def friction_factor(v1: 'int', v2: 'double[2]') -> 'int':
 
 
 specs = HookSpecs(
-    project_name='ACME',
-    version='1',
-    pyd_name='_test_hook_man_generator',
-    hooks=[
-        friction_factor,
-    ],
+    project_name="ACME", version="1", pyd_name="_test_hook_man_generator", hooks=[friction_factor]
 )
